@@ -240,7 +240,8 @@ def print_help():
         print "  -d  --daemon             Use when run as a service"
     else:
         print "  -d  --daemon             Fork daemon process"
-        print "      --pid <path>         Create a PID file in the listed folder (full path)"
+        print "      --pid <path>         Create a PID file in the given folder (full path)"
+        print "      --pidfile <path>     Create a PID file with the given name (full path)"
     print
     print "      --force              Discard web-port timeout (see Wiki!)"
     print "  -h  --help               Print this message"
@@ -843,7 +844,7 @@ def commandline_handler(frozen=True):
                                     'weblogging=', 'server=', 'templates', 'no_ipv6',
                                     'template2', 'browser=', 'config-file=', 'force',
                                     'version', 'https=', 'autorestarted', 'repair', 'repair-all',
-                                    'log-all', 'no-login', 'pid=', 'new', 'sessions', 'console',
+                                    'log-all', 'no-login', 'pid=', 'new', 'sessions', 'console', 'pidfile=',
                                     # Below Win32 Service options
                                     'password=', 'username=', 'startup=', 'perfmonini=', 'perfmondll=',
                                     'interactive', 'wait=',
@@ -915,6 +916,7 @@ def main():
     no_login = False
     re_argv = [sys.argv[0]]
     pid_path = None
+    pid_file = None
     new_instance = False
     force_sessions = False
     osx_console = False
@@ -997,6 +999,10 @@ def main():
             pid_path = arg
             re_argv.append(opt)
             re_argv.append(arg)
+        elif opt in ('--pidfile',):
+            pid_file = arg
+            re_argv.append(opt)
+            re_argv.append(arg)
         elif opt in ('--new',):
             new_instance = True
         elif opt in ('--sessions',):
@@ -1270,6 +1276,25 @@ def main():
     logging.info('Python-version = %s', sys.version)
     logging.info('Arguments = %s', sabnzbd.CMDLINE)
 
+    if sabnzbd.cfg.log_level() > 1:
+        try:
+            s_ipv4 = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+            s_ipv4.connect(('google.com', 80))
+            logging.debug('My IPv4 address = %s', s_ipv4.getsockname()[0])
+            s_ipv4.close()
+        except:
+            logging.debug('Could not determine my IPv4 address')
+            pass
+        
+        try:
+            s_ipv6 = socket.socket(socket.AF_INET6, socket.SOCK_DGRAM)
+            s_ipv6.connect(('ipv6.google.com', 80))
+            logging.debug('My IPv6 address = %s', s_ipv6.getsockname()[0])
+            s_ipv6.close()
+        except:
+            logging.debug('Could not determine my IPv6 address')
+            pass
+
     # OSX 10.5 I/O priority setting
     if sabnzbd.DARWIN:
         logging.info('[osx] IO priority setting')
@@ -1318,6 +1343,8 @@ def main():
     sabnzbd.WEB_COLOR2 = CheckColor(sabnzbd.cfg.web_color2(),  web_dir2)
     sabnzbd.cfg.web_color2.set(sabnzbd.WEB_COLOR2)
 
+    logging.debug('Unwanted extensions are ... %s',sabnzbd.cfg.unwanted_extensions())
+
     if fork and not sabnzbd.WIN32:
         daemonize()
 
@@ -1545,8 +1572,8 @@ def main():
             # Write URL directly to registry
             set_connection_info(api_url)
 
-    if pid_path:
-        sabnzbd.pid_file(pid_path, cherryport)
+    if pid_path or pid_file:
+        sabnzbd.pid_file(pid_path, pid_file, cherryport)
 
     # Start all SABnzbd tasks
     logging.info('Starting %s-%s', sabnzbd.MY_NAME, sabnzbd.__version__)
