@@ -169,33 +169,33 @@ jQuery(function($){
   // Refresh rate
   $("#refreshRate-option").val($.plush.refreshRate).change( function() {
     $.plush.refreshRate = $("#refreshRate-option").val();
-    $.cookie('plushRefreshRate', $.plush.refreshRate, { expires: 365, path: '/'  });
+    $.cookie('plushRefreshRate', $.plush.refreshRate, { expires: 365 });
     $.plush.Refresh();
   });
 
   // Container width
   $("#containerWidth-option").val($.plush.containerWidth).change( function() {
     $.plush.containerWidth = $("#containerWidth-option").val();
-    $.cookie('plushContainerWidth', $.plush.containerWidth, { expires: 365, path: '/' });
+    $.cookie('plushContainerWidth', $.plush.containerWidth, { expires: 365 });
     $('#master-width').css('width',$.plush.containerWidth);
   }).trigger('change');
 
   // Confirm Queue Deletions toggle
   $("#confirmDeleteQueue").prop('checked', $.plush.confirmDeleteQueue ).change( function() {
     $.plush.confirmDeleteQueue = $("#confirmDeleteQueue").prop('checked');
-    $.cookie('plushConfirmDeleteQueue', $.plush.confirmDeleteQueue ? 1 : 0, { expires: 365, path: '/'  });
+    $.cookie('plushConfirmDeleteQueue', $.plush.confirmDeleteQueue ? 1 : 0, { expires: 365 });
   });
 
   // Confirm History Deletions toggle
   $("#confirmDeleteHistory").prop('checked', $.plush.confirmDeleteHistory ).change( function() {
     $.plush.confirmDeleteHistory = $("#confirmDeleteHistory").prop('checked');
-    $.cookie('plushConfirmDeleteHistory', $.plush.confirmDeleteHistory ? 1 : 0, { expires: 365, path: '/'  });
+    $.cookie('plushConfirmDeleteHistory', $.plush.confirmDeleteHistory ? 1 : 0, { expires: 365 });
   });
 
   // Block Refreshes on Hover toggle
   $("#blockRefresh").prop('checked', $.plush.blockRefresh ).change( function() {
     $.plush.blockRefresh = $("#blockRefresh").prop('checked');
-    $.cookie('plushBlockRefresh', $.plush.blockRefresh ? 1 : 0, { expires: 365, path: '/'  });
+    $.cookie('plushBlockRefresh', $.plush.blockRefresh ? 1 : 0, { expires: 365 });
   });
 
   // Sabnzbd restart
@@ -352,7 +352,7 @@ jQuery(function($){
       $.plush.multiOpsChecks = new Array();
       $('<input type="checkbox" class="multiops" />').appendTo('#queue tr td.nzb_status_col');
     }
-    $.cookie('plushMultiOps', $.plush.multiOps ? 1 : 0, { expires: 365, path: '/'  });
+    $.cookie('plushMultiOps', $.plush.multiOps ? 1 : 0, { expires: 365 });
   });
   if ($.plush.multiOps)
     $('#multiops_toggle').trigger('click');
@@ -365,7 +365,7 @@ jQuery(function($){
       $('#topmenu_bar').show();
       $.plush.noTopMenu = false;
     }
-    $.cookie('plushNoTopMenu', $.plush.noTopMenu ? 1 : 0, { expires: 365, path: '/'  });
+    $.cookie('plushNoTopMenu', $.plush.noTopMenu ? 1 : 0, { expires: 365 });
   });
   if ($.plush.noTopMenu)
     $('#topmenu_toggle').trigger('click');
@@ -521,7 +521,7 @@ jQuery(function($){
   $("#queue-pagination-perpage").change(function(event){
     $.plush.queuecurpage = Math.floor($.plush.queuecurpage * $.plush.queuePerPage / $(event.target).val() );
     $.plush.queuePerPage = $(event.target).val();
-    $.cookie('plushQueuePerPage', $.plush.queuePerPage, { expires: 365, path: '/'  });
+    $.cookie('plushQueuePerPage', $.plush.queuePerPage, { expires: 365 });
     $.plush.queueforcerepagination = true;
     $.plush.RefreshQueue();
   });
@@ -948,7 +948,7 @@ $("a","#multiops_inputs").click(function(e){
   $("#history-pagination-perpage").change(function(event){
     $.plush.histcurpage = Math.floor($.plush.histcurpage * $.plush.histPerPage / $(event.target).val() );
     $.plush.histPerPage = $(event.target).val();
-    $.cookie('plushHistPerPage', $.plush.histPerPage, { expires: 365, path: '/'  });
+    $.cookie('plushHistPerPage', $.plush.histPerPage, { expires: 365 });
     $.plush.histforcerepagination = true;
     if ($.plush.histPerPage=="1")
       $("#history-pagination").html(''); // pagination rebuild not triggered on blank history (disabled)
@@ -1033,7 +1033,7 @@ $("a","#multiops_inputs").click(function(e){
   // show all / show failed
   $('#failed_only').change(function(){
     $.plush.failedOnly = $("#failed_only").val();
-    $.cookie('plushFailedOnly', $.plush.failedOnly, { expires: 365, path: '/'  });
+    $.cookie('plushFailedOnly', $.plush.failedOnly, { expires: 365 });
     $.plush.RefreshHistory();
   }).val($.plush.failedOnly);
 
@@ -1047,6 +1047,12 @@ $("a","#multiops_inputs").click(function(e){
     title:function(){return $(this).text();},
     innerWidth:"80%", innerHeight:"300px", initialWidth:"80%", initialHeight:"300px", speed:0, opacity:0.7 });
 
+  // modal for reporting issues  
+  $("#historyTable .modal-report").colorbox({ inline:true,
+    href: function(){return "#report-"+$(this).parent().parent().parent().attr('id');},
+    title:function(){return $(this).text();},
+    innerWidth:"250px", innerHeight:"110px", initialWidth:"250px", initialHeight:"110px", speed:0, opacity:0.7 });
+
   // Build pagination only when needed
   if ($.plush.histPerPage=="1") // disabled history
     $("#history-pagination").html(''); // remove pages if history empty
@@ -1073,6 +1079,55 @@ $.plush.histprevslots = $.plush.histnoofslots; // for the next refresh
 
   }); // end livequery
 
+  $('.user_combo').livequery('change', function(){
+    var nzo_id = $(this).parent().parent().parent().parent().attr('id');
+    var videoAudio = $(this).hasClass('video') ? 'video' : 'audio';
+    $.ajax({
+      headers: {"Cache-Control": "no-cache"},
+      type: "POST",
+      url: "tapi",
+      data: {mode:'queue', name:'rating', value: nzo_id, type: videoAudio, setting: $(this).val(), apikey: $.plush.apikey},
+      success: $.plush.RefreshHistory
+    });
+  });
+
+  $('.user_vote').livequery('click', function(){
+    var nzo_id = $(this).parent().parent().parent().attr('id');
+    var upDown = $(this).hasClass('up') ? 'up' : 'down';
+    $.ajax({
+      headers: {"Cache-Control": "no-cache"},
+      type: "POST",
+      url: "tapi",
+      data: {mode:'queue', name:'rating', value: nzo_id, type: 'vote', setting: upDown, apikey: $.plush.apikey},
+      success: $.plush.RefreshHistory
+    });
+  });
+
+  $('#history .show_flags').live('click', function(){
+    $('#flag_modal_job').val( $(this).parent().parent().parent().attr('id') );
+    $.colorbox({ inline:true, href:"#flag_modal", title:$(this).text(),
+      innerWidth:"500px", innerHeight:"185px", initialWidth:"500px", initialHeight:"185px", speed:0, opacity:0.7
+    });
+    return false;
+  });
+  $('#flag_modal input:submit').click(function(){
+    var nzo_id = $('#flag_modal_job').val();
+    var flag = $('input[name=rating_flag]:checked', '#flag_modal').val();
+    var expired_host = $('input[name=expired_host]', '#flag_modal').val();
+    var other = $('input[name=other]', '#flag_modal').val();
+    var comment = $('input[name=comment]', '#flag_modal').val();
+    var _detail = (flag == 'comment') ? comment : ((flag == 'other') ? other : expired_host);
+    $.colorbox.close();
+    $.plush.modalOpen=false;
+    $.ajax({
+      headers: {"Cache-Control": "no-cache"},
+      type: "POST",
+      url: "tapi",
+      data: {mode:'queue', name:'rating', value: nzo_id, type: 'flag', setting: flag, detail: _detail, apikey: $.plush.apikey},
+      success: $.plush.RefreshHistory
+    });
+  });
+  
   }, // end $.plush.InitHistory()
 
 
@@ -1132,6 +1187,8 @@ $.plush.histprevslots = $.plush.histnoofslots; // for the next refresh
 
   $('.left_stats .initial-loading').hide();
   $('#queue').html(result);               // Replace queue contents with queue.tmpl
+  $('#queue .avg_rate').rateit({readonly: true, resetable: false, step: 0.5});
+  $('#queue .avg_rate').each(function() { $(this).rateit('value', $(this).attr('value') / 2); });
 
   if ($.plush.multiOps) // add checkboxes
     $('<input type="checkbox" class="multiops" />').appendTo('#queue tr td.nzb_status_col');
@@ -1187,6 +1244,11 @@ $.plush.histprevslots = $.plush.histnoofslots; // for the next refresh
       }
       $('.left_stats .initial-loading').hide();
       $('#history').html(result);               // Replace history contents with history.tmpl
+      $('#history .avg_rate').rateit({readonly: true, resetable: false, step: 0.5});
+      $('#history .avg_rate').each(function() { $(this).rateit('value', $(this).attr('value') / 2); });
+      $('#history .user_combo option').filter(function() {
+        return $(this).attr('value') == $(this).parent().parent().find('input.user_combo').attr('value'); 
+      }).attr('selected', true);
       $('#history-pagination span').removeClass('loading'); // Remove spinner graphic from pagination
     }
   });
