@@ -58,6 +58,7 @@ from sabnzbd.postproc import PostProcessor
 from sabnzbd.articlecache import ArticleCache
 from sabnzbd.utils.servertests import test_nntp_server_dict
 from sabnzbd.newzbin import Bookmarks
+from sabnzbd.rating import Rating
 from sabnzbd.bpsmeter import BPSMeter
 from sabnzbd.database import build_history_info, unpack_history_info, get_history_handle
 import sabnzbd.growler
@@ -270,6 +271,24 @@ def _api_queue_default(output, value, kwargs):
     else:
         return report(output, _MSG_NOT_IMPLEMENTED)
 
+def _api_queue_rating(output, value, kwargs):
+    """ API: accepts output, value(=nzo_id), type, setting, detail """
+    vote_map = {'up': Rating.VOTE_UP, 'down': Rating.VOTE_DOWN}
+    flag_map = {'spam': Rating.FLAG_SPAM, 'encrypted': Rating.FLAG_ENCRYPTED, 'expired': Rating.FLAG_EXPIRED, 'other': Rating.FLAG_OTHER, 'comment': Rating.FLAG_COMMENT}    
+    type = kwargs.get('type')
+    setting = kwargs.get('setting')
+    if value:
+        try:
+            video = setting if type == 'video' and setting != "-" else None
+            audio = setting if type == 'audio' and setting != "-" else None
+            vote = vote_map[setting] if type == 'vote' else None
+            flag = flag_map[setting] if type == 'flag' else None
+            Rating.do.update_user_rating(value, video, audio, vote, flag, kwargs.get('detail'))
+            return report(output)
+        except:
+            return report(output, _MSG_BAD_SERVER_PARMS)
+    else:
+        return report(output, _MSG_NO_VALUE)
 
 #------------------------------------------------------------------------------
 def _api_options(name, output, kwargs):
@@ -639,6 +658,12 @@ def _api_resume_pp(name, output, kwargs):
     return report(output)
 
 
+def _api_pause_pp(name, output, kwargs):
+    """ API: accepts output """
+    PostProcessor.do.paused = True
+    return report(output)
+
+
 def _api_rss_now(name, output, kwargs):
     """ API: accepts output """
     # Run RSS scan async, because it can take a long time
@@ -657,7 +682,8 @@ def _api_test_email(name, output, kwargs):
     pack['unpack'] = ['action 1', 'action 2']
     res = sabnzbd.emailer.endjob('I had a d\xe8ja vu', 123, 'unknown', True,
                                  os.path.normpath(os.path.join(cfg.complete_dir.get_path(), '/unknown/I had a d\xe8ja vu')),
-                                 123*MEBI, None, pack, 'my_script', 'Line 1\nLine 2\nLine 3\nd\xe8ja vu\n', 0)
+                                 123*MEBI, None, pack, 'my_script', 'Line 1\nLine 2\nLine 3\nd\xe8ja vu\n', 0,
+                                 test=kwargs)
     if res == 'Email succeeded':
         res = None
     return report(output, error=res)
@@ -665,7 +691,7 @@ def _api_test_email(name, output, kwargs):
 def _api_test_notif(name, output, kwargs):
     """ API: send a test notification, return result """
     logging.info("Sending test notification")
-    res = sabnzbd.growler.send_notification('SABnzbd', T('Test Notification'), 'other', wait=True)
+    res = sabnzbd.growler.send_notification('SABnzbd', T('Test Notification'), 'other', wait=True, test=kwargs)
     return report(output, error=res)
 
 def _api_undefined(name, output, kwargs):
@@ -764,8 +790,22 @@ def _api_config_undefined(output, kwargs):
     return report(output, _MSG_NOT_IMPLEMENTED)
 
 
+def _api_server_stats(name, output, kwargs):
+    """ API: accepts output """
+    sum_t, sum_m, sum_w, sum_d = BPSMeter.do.get_sums()
+    stats = {'total': sum_t, 'month': sum_m, 'week': sum_w, 'day': sum_d}
+
+    stats['servers'] = {}
+    for svr in config.get_servers():
+       t, m, w, d = BPSMeter.do.amounts(svr)
+       stats['servers'][svr] = {'total': t or 0, 'month': m or 0, 'week': w or 0, 'day': d or 0}
+
+    return report(output, keyword='', data=stats)
+
+
 #------------------------------------------------------------------------------
 _api_table = {
+    'server_stats'    : _api_server_stats,
     'get_config'      : _api_get_config,
     'set_config'      : _api_set_config,
     'del_config'      : _api_del_config,
@@ -803,6 +843,7 @@ _api_table = {
     'eval_sort'       : _api_eval_sort,
     'watched_now'     : _api_watched_now,
     'resume_pp'       : _api_resume_pp,
+    'pause_pp'        : _api_pause_pp,
     'rss_now'         : _api_rss_now,
     'browse'          : _api_browse,
     'reset_quota'     : _api_reset_quota,
@@ -819,7 +860,8 @@ _api_queue_table = {
     'pause'                   : _api_queue_pause,
     'resume'                  : _api_queue_resume,
     'priority'                : _api_queue_priority,
-    'sort'                    : _api_queue_sort
+    'sort'                    : _api_queue_sort,
+    'rating'                  : _api_queue_rating
 }
 
 _api_config_table = {
@@ -1044,6 +1086,7 @@ def build_queue(web_dir=None, root=None, verbose=False, prim=True, webdir='', ve
     info['script_list'] = list_scripts()
     info['cat_list'] = list_cats(output is None)
 
+    info['rating_enable'] = bool(cfg.rating_enable())                                                                           
 
     n = 0
     found_active = False
@@ -1139,7 +1182,8 @@ def build_queue(web_dir=None, root=None, verbose=False, prim=True, webdir='', ve
             slot['percentage'] = "%s" % (int(((mb-mbleft) / mb) * 100))
         slot['missing'] = missing
 
-        if Downloader.do.paused or Downloader.do.postproc or status not in (Status.DOWNLOADING, Status.QUEUED):
+        if (Downloader.do.paused or Downloader.do.postproc or status not in (Status.DOWNLOADING, Status.QUEUED)) \
+           and priority != TOP_PRIORITY:
             slot['timeleft'] = '0:00:00'
             slot['eta'] = 'unknown'
         else:
@@ -1212,8 +1256,13 @@ def build_queue(web_dir=None, root=None, verbose=False, prim=True, webdir='', ve
             slot['finished'] = finished
             slot['active'] = active
             slot['queued'] = queued
-
-
+        
+        rating = Rating.do.get_rating_by_nzo(nzo_id)
+        slot['has_rating'] = rating is not None
+        if rating:
+            slot['rating_avg_video'] = rating.avg_video
+            slot['rating_avg_audio'] = rating.avg_audio
+                                                                               
         if (start <= n  and n < start + limit) or not limit:
             slotinfo.append(slot)
         n += 1
@@ -1761,6 +1810,20 @@ def build_history(start=None, limit=None, verbose=False, verbose_list=None, sear
         if item['retry']:
             retry_folders.append(path)
 
+        if Rating.do:
+            rating = Rating.do.get_rating_by_nzo(item['nzo_id'])
+        else:
+            rating = None
+        item['has_rating'] = rating is not None
+        if rating:
+            item['rating_avg_video'] = rating.avg_video
+            item['rating_avg_audio'] = rating.avg_audio
+            item['rating_avg_vote_up'] = rating.avg_vote_up
+            item['rating_avg_vote_down'] = rating.avg_vote_down
+            item['rating_user_video'] = rating.user_video
+            item['rating_user_audio'] = rating.user_audio
+            item['rating_user_vote'] = rating.user_vote
+            
     total_items += full_queue_size
     fetched_items = len(items)
 
