@@ -24,6 +24,7 @@ import Queue
 import binascii
 import logging
 import struct
+import re
 from threading import Thread
 from time import sleep
 try:
@@ -49,7 +50,7 @@ from sabnzbd.encoding import latin1, unicoder, is_utf8
 class Assembler(Thread):
     do = None # Link to the instance of this method
 
-    def __init__ (self, queue = None):
+    def __init__(self, queue=None):
         Thread.__init__(self)
 
         if queue:
@@ -100,7 +101,7 @@ class Assembler(Thread):
                             # Pause without saving
                             sabnzbd.downloader.Downloader.do.pause(save=False)
                     except:
-                        logging.error('Fatal error in Assembler', exc_info = True)
+                        logging.error('Fatal error in Assembler', exc_info=True)
                         break
 
                     nzf.remove_admin()
@@ -120,6 +121,22 @@ class Assembler(Thread):
                             nzo.fail_msg = T('Aborted, encryption detected')
                             import sabnzbd.nzbqueue
                             sabnzbd.nzbqueue.NzbQueue.do.end_job(nzo)
+
+                    unwanted = rar_contains_unwanted_file(filepath)
+                    if unwanted:
+                        logging.warning(Ta('WARNING: In "%s" unwanted extension in RAR file. Unwanted file is %s '), latin1(nzo.final_name), unwanted)
+                        logging.debug(Ta('Unwanted extension is in rar file %s'), filepath)
+                        if cfg.action_on_unwanted_extensions() == 1:
+                            logging.debug('Unwanted extension ... pausing')
+                            nzo.unwanted_ext = True
+                            nzo.pause()
+                        if cfg.action_on_unwanted_extensions() == 2:
+                            logging.debug('Unwanted extension ... aborting')
+                            nzo.fail_msg = T('Aborted, unwanted extension detected')
+                            import sabnzbd.nzbqueue
+                            sabnzbd.nzbqueue.NzbQueue.do.end_job(nzo)
+
+
                     nzf.completed = True
             else:
                 sabnzbd.nzbqueue.NzbQueue.do.remove(nzo.nzo_id, add_to_history=False, cleanup=False)
@@ -128,7 +145,7 @@ class Assembler(Thread):
 
 def _assemble(nzf, path, dupe):
     if os.path.exists(path):
-        unique_path = get_unique_path(path, create_dir = False)
+        unique_path = get_unique_path(path, create_dir=False)
         if dupe:
             path = unique_path
         else:
@@ -239,7 +256,7 @@ def GetMD5Hashes(fname, force=False):
             table = {}
         except:
             logging.debug('QuickCheck parser crashed in file %s', fname)
-            logging.info('Traceback: ', exc_info = True)
+            logging.info('Traceback: ', exc_info=True)
             table = {}
 
         f.close()
@@ -287,6 +304,7 @@ def ParseFilePacket(f, header):
     return nothing
 
 
+RE_SUBS = re.compile(r'\W+sub|subs|subpack|subtitle|subtitles(?![a-z])', re.I)
 def is_cloaked(path, names):
     """ Return True if this is likely to be a cloaked encrypted post """
     fname = unicoder(os.path.split(path)[1]).lower()
@@ -294,8 +312,7 @@ def is_cloaked(path, names):
     for name in names:
         name = os.path.split(name.lower())[1]
         name, ext = os.path.splitext(unicoder(name))
-        if ext == u'.rar' and fname.startswith(name) and (len(fname) - len(name)) < 8 and \
-           '.subs' not in fname:
+        if ext == u'.rar' and fname.startswith(name) and (len(fname) - len(name)) < 8 and len(names) < 3 and not RE_SUBS.search(fname):
             logging.debug('File %s is probably encrypted due to RAR with same name inside this RAR', fname)
             return True
         elif 'password' in name:
@@ -321,3 +338,27 @@ def check_encrypted_rar(nzo, filepath):
             logging.debug('RAR file %s cannot be inspected', filepath)
     return encrypted
 
+
+def rar_contains_unwanted_file(filepath):
+    # checks for unwanted extensions in the rar file 'filepath'
+    # ... unwanted extensions are defined in global variable cfg.unwanted_extensions()
+    # returns False if no unwanted extensions are found in the rar file
+    # returns name of file if unwanted extension is found in the rar file
+    unwanted = None
+    if is_rarfile(filepath):
+        #logging.debug('rar file to check: %s',filepath)
+        #logging.debug('unwanted extensions are: %s', cfg.unwanted_extensions())
+        try:
+            zf = RarFile(filepath, all_names=True)
+            #logging.debug('files in rar file: %s', zf.namelist())
+            for somefile in zf.namelist() :
+                logging.debug('file in rar file: %s', somefile)
+                if os.path.splitext(somefile)[1].replace('.', '').lower() in cfg.unwanted_extensions():
+                    logging.debug('Unwanted file %s', somefile)
+                    unwanted = somefile
+                    zf.close()
+        except:
+            logging.debug('RAR file %s cannot be inspected.', filepath)
+    return unwanted
+
+
