@@ -94,6 +94,7 @@ enable_par_cleanup = OptionBool('misc', 'enable_par_cleanup', True)
 never_repair = OptionBool('misc', 'never_repair', False)
 ignore_unrar_dates = OptionBool('misc', 'ignore_unrar_dates', False)
 overwrite_files = OptionBool('misc', 'overwrite_files', False)
+flat_unpack = OptionBool('misc', 'flat_unpack', False)
 
 par_option = OptionStr('misc', 'par_option', '', validation=no_nonsense)
 nice = OptionStr('misc', 'nice',  '', validation=no_nonsense)
@@ -113,6 +114,11 @@ newzbin_unbookmark = OptionBool('newzbin', 'unbookmark', True)
 bookmark_rate = OptionNumber('newzbin', 'bookmark_rate', 60, minval=15, maxval=24*60)
 newzbin_url = OptionStr('newzbin', 'url', 'www.newzbin2.es')
 
+rating_enable = OptionBool('misc', 'rating_enable', False)
+rating_host = OptionStr('misc', 'rating_host', 'www.oznzb.com')
+rating_api_key = OptionStr('misc', 'rating_api_key')
+rating_feedback = OptionBool('misc', 'rating_feedback', True)
+
 top_only = OptionBool('misc', 'top_only', False)
 autodisconnect = OptionBool('misc', 'auto_disconnect', True)
 queue_complete = OptionStr('misc', 'queue_complete')
@@ -128,6 +134,7 @@ folder_rename = OptionBool('misc', 'folder_rename', True)
 folder_max_length = OptionNumber('misc', 'folder_max_length', DEF_FOLDER_MAX, 20, 65000)
 pause_on_pwrar = OptionBool('misc', 'pause_on_pwrar', True)
 prio_sort_list = OptionList('misc', 'prio_sort_list')
+enable_meta = OptionBool('misc', 'enable_meta', True)
 
 safe_postproc = OptionBool('misc', 'safe_postproc', True)
 empty_postproc = OptionBool('misc', 'empty_postproc', False)
@@ -205,6 +212,9 @@ web_color2 = OptionStr('misc', 'web_color2')
 cleanup_list = OptionList('misc', 'cleanup_list')
 warned_old_queue = OptionBool('misc', 'warned_old_queue', False)
 
+unwanted_extensions = OptionList('misc', 'unwanted_extensions')
+action_on_unwanted_extensions = OptionNumber('misc', 'action_on_unwanted_extensions', 0)
+
 log_web = OptionBool('logging', 'enable_cherrypy_logging', False)
 log_dir = OptionDir('misc', 'log_dir', 'logs', validation=validate_notempty)
 log_level = OptionNumber('logging', 'log_level', 1, -1, 2)
@@ -260,6 +270,9 @@ wait_ext_drive = OptionNumber('misc', 'wait_ext_drive', 5, 1, 60)
 history_limit = OptionNumber('misc', 'history_limit', 50, 0)
 show_sysload = OptionNumber('misc', 'show_sysload', 2, 0, 2)
 web_watchdog = OptionBool('misc', 'web_watchdog', False)
+warn_dupl_jobs = OptionBool('misc', 'warn_dupl_jobs', True)
+new_nzb_on_failure = OptionBool('misc', 'new_nzb_on_failure', False)
+
 
 #------------------------------------------------------------------------------
 # Set root folders for Folder config-items
@@ -279,4 +292,4 @@ def set_root_folders(home, lcldata):
 def set_root_folders2():
     https_cert.set_root(admin_dir.get_path())
     https_key.set_root(admin_dir.get_path())
-    https_chain.set_root(admin_dir.get_path())
\ No newline at end of file
+    https_chain.set_root(admin_dir.get_path())
