@@ -119,6 +119,7 @@ def ProcessArchiveFile(filename, path, pp=None, script=None, cat=None, catdir=No
                         nzo = None
                     if nzo:
                         nzo_ids.append(add_nzo(nzo))
+                        nzo.update_rating()
         zf.close()
         try:
             if not keep: os.remove(path)
@@ -169,6 +170,9 @@ def ProcessSingleFile(filename, path, pp=None, script=None, cat=None, catdir=Non
     if name:
         name, cat = name_to_cat(name, catdir)
         # The name is used as the name of the folder, so sanitize it using folder specific santization
+        if not nzbname:
+            # Prevent embedded password from being damaged by sanitize and trimming
+            nzbname = os.path.split(name)[1]
         name = misc.sanitize_foldername(name)
 
     try:
@@ -189,6 +193,7 @@ def ProcessSingleFile(filename, path, pp=None, script=None, cat=None, catdir=Non
 
     if nzo:
         nzo_ids.append(add_nzo(nzo))
+        nzo.update_rating()
     try:
         if not keep: os.remove(path)
     except:
