@@ -39,6 +39,7 @@ from sabnzbd.misc import real_path, to_units, \
 from sabnzbd.panic import panic_old_queue
 from sabnzbd.newswrapper import GetServerParms
 from sabnzbd.newzbin import Bookmarks
+from sabnzbd.rating import Rating
 from sabnzbd.bpsmeter import BPSMeter
 from sabnzbd.encoding import TRANS, xml_name, LatinFilter, unicoder, special_fixer, \
                              platform_encode, latin1, encode_for_xml
@@ -543,7 +544,7 @@ class NzoPage(object):
                 filename_pw = xml_name(nzo.final_name_pw_clean)
                 filename = xml_name(nzo.final_name)
                 if nzo.password:
-                    password = xml_name(nzo.password)
+                    password = xml_name(nzo.password).replace('"', '&quot;')
                 else:
                     password = ''
                 priority = pnfo[PNFO_PRIORITY_FIELD]
@@ -601,6 +602,8 @@ class NzoPage(object):
         index = kwargs.get('index', None)
         name = kwargs.get('name', None)
         password = kwargs.get('password', None)
+        if password == "":
+            password = None
         pp = kwargs.get('pp', None)
         script = kwargs.get('script', None)
         cat = kwargs.get('cat', None)
@@ -612,7 +615,7 @@ class NzoPage(object):
         if name != None:
             NzbQueue.do.change_name(nzo_id, special_fixer(name), password)
         if cat != None:
-            NzbQueue.do.change_cat(nzo_id,cat)
+            NzbQueue.do.change_cat(nzo_id, cat, priority)
         if script != None:
             NzbQueue.do.change_script(nzo_id,script)
         if pp != None:
@@ -878,7 +881,8 @@ class HistoryPage(object):
         self.__verbose_list = []
         self.__failed_only = False
         self.__prim = prim
-
+        self.__edit_rating = None
+        
     @cherrypy.expose
     def index(self, **kwargs):
         if not check_access(): return Protected()
@@ -894,6 +898,8 @@ class HistoryPage(object):
         history['isverbose'] = self.__verbose
         history['failed_only'] = failed_only
 
+        history['rating_enable'] = bool(cfg.rating_enable())
+
         if cfg.newzbin_username() and cfg.newzbin_password():
             history['newzbinDetails'] = True
 
@@ -908,6 +914,12 @@ class HistoryPage(object):
 
         history['lines'], history['fetched'], history['noofslots'] = build_history(limit=limit, start=start, verbose=self.__verbose, verbose_list=self.__verbose_list, search=search, failed_only=failed_only)
 
+        for line in history['lines']:
+            if self.__edit_rating is not None and line.get('nzo_id') == self.__edit_rating:
+                line['edit_rating'] = True 
+            else:
+                line['edit_rating'] = '' 
+        
         if search:
             history['search'] = escape(search)
         else:
@@ -1026,6 +1038,29 @@ class HistoryPage(object):
         del_hist_job(job, del_files=True)
         raise dcRaiser(self.__root, kwargs)
 
+    @cherrypy.expose
+    def show_edit_rating(self, **kwargs):
+        msg = check_session(kwargs)
+        if msg: return msg
+        self.__edit_rating = kwargs.get('job');
+        raise queueRaiser(self.__root, kwargs)
+
+    @cherrypy.expose
+    def action_edit_rating(self, **kwargs):
+        flag_map = {'spam': Rating.FLAG_SPAM, 'encrypted': Rating.FLAG_ENCRYPTED, 'expired': Rating.FLAG_EXPIRED}    
+        msg = check_session(kwargs)
+        if msg: return msg
+        try:
+            if kwargs.get('send'):
+                video = kwargs.get('video') if kwargs.get('video') != "-" else None 
+                audio = kwargs.get('audio') if kwargs.get('audio') != "-" else None                
+                flag = flag_map.get(kwargs.get('rating_flag'))
+                detail = kwargs.get('expired_host') if kwargs.get('expired_host') != '<Host>' else None
+                Rating.do.update_user_rating(kwargs.get('job'), video, audio, flag, detail) 
+        except:
+            pass
+        self.__edit_rating = None;
+        raise queueRaiser(self.__root, kwargs)
 
 #------------------------------------------------------------------------------
 class ConfigPage(object):
@@ -1176,7 +1211,9 @@ SWITCH_LIST = \
              'ignore_samples', 'pause_on_post_processing', 'quick_check', 'nice', 'ionice',
              'ssl_type', 'pre_script', 'pause_on_pwrar', 'ampm', 'sfv_check', 'folder_rename',
              'unpack_check', 'quota_size', 'quota_day', 'quota_resume', 'quota_period',
-             'pre_check', 'max_art_tries', 'max_art_opt', 'fail_hopeless'
+             'pre_check', 'max_art_tries', 'max_art_opt', 'fail_hopeless',
+             'rating_enable', 'rating_api_key', 'rating_host', 'rating_feedback',
+             'unwanted_extensions', 'action_on_unwanted_extensions'
              )
 
 #------------------------------------------------------------------------------
@@ -1199,6 +1236,7 @@ class ConfigSwitches(object):
 
         for kw in SWITCH_LIST:
             conf[kw] = config.get_config('misc', kw)()
+        conf['unwanted_extensions'] = cfg.unwanted_extensions.get_string()
 
         conf['script_list'] = list_scripts() or ['None']
         conf['have_ampm'] = HAVE_AMPM
@@ -1215,6 +1253,8 @@ class ConfigSwitches(object):
         for kw in SWITCH_LIST:
             item = config.get_config('misc', kw)
             value = platform_encode(kwargs.get(kw))
+            if kw == 'unwanted_extensions' and value:
+                value = value.lower().replace('.', '')
             msg = item.set(value)
             if msg:
                 return badParameterResponse(msg)
@@ -1231,8 +1271,8 @@ SPECIAL_BOOL_LIST = \
               'never_repair', 'allow_streaming', 'ignore_unrar_dates', 'rss_filenames',
               'osx_menu', 'osx_speed', 'win_menu', 'uniconfig', 'use_pickle', 'allow_incomplete_nzb',
               'randomize_server_ip', 'no_ipv6', 'keep_awake', 'overwrite_files', 'empty_postproc',
-              'web_watchdog', 'wait_for_dfolder', 'warn_empty_nzb', 'enable_recursive', 'sanitize_safe'
-
+              'web_watchdog', 'wait_for_dfolder', 'warn_empty_nzb', 'enable_recursive', 'sanitize_safe',
+              'enable_meta', 'flat_unpack', 'warn_dupl_jobs', 'new_nzb_on_failure'
             )
 SPECIAL_VALUE_LIST = \
             ( 'size_limit', 'folder_max_length', 'fsys_type', 'movie_rename_limit', 'nomedia_marker',
