@@ -94,7 +94,7 @@ def find_programs(curdir):
 
     if sabnzbd.DARWIN:
         try:
-            os_version = subprocess.Popen("sw_vers -productVersion", stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).stdout.read()
+            os_version = run_simple('sw_vers -productVersion')
             #par2-sl from Macpar Deluxe 4.1 is only 10.6 and later
             if int(os_version.split('.')[1]) >= 6:
                 sabnzbd.newsunpack.PAR2_COMMAND = check(curdir, 'osx/par2/par2-sl')
@@ -129,19 +129,22 @@ def find_programs(curdir):
         sabnzbd.newsunpack.RAR_PROBLEM = not unrar_check(sabnzbd.newsunpack.RAR_COMMAND)
 
 #------------------------------------------------------------------------------
-def external_processing(extern_proc, complete_dir, filename, msgid, nicename, cat, group, status):
+def external_processing(extern_proc, complete_dir, filename, msgid, nicename, cat, group, status, failure_url):
     """ Run a user postproc script, return console output and exit value
     """
     command = [str(extern_proc), str(complete_dir), str(filename),
                str(nicename), str(msgid), str(cat), str(group), str(status)]
 
+    if failure_url:
+        command.extend(str(failure_url))
+
     if extern_proc.endswith('.py') and (sabnzbd.WIN32 or not os.access(extern_proc, os.X_OK)):
         command.insert(0, 'python')
     stup, need_shell, command, creationflags = build_command(command)
     env = fix_env()
 
-    logging.info('Running external script %s(%s, %s, %s, %s, %s, %s, %s)',
-                 extern_proc, complete_dir, filename, nicename, msgid, cat, group, status)
+    logging.info('Running external script %s(%s, %s, %s, %s, %s, %s, %s, %s)',
+                 extern_proc, complete_dir, filename, nicename, msgid, cat, group, status, failure_url)
 
     try:
         p = subprocess.Popen(command, shell=need_shell, stdin=subprocess.PIPE,
@@ -188,7 +191,8 @@ def unpack_magic(nzo, workdir, workdir_complete, dele, one_folder, joinables, zi
 
     rerun = False
     newfiles = []
-    error = False
+    error = 0
+    new_joins = new_rars = new_zips = new_ts = None
 
     if cfg.enable_filejoin():
         new_joins = [jn for jn in xjoinables if jn not in joinables]
@@ -218,7 +222,7 @@ def unpack_magic(nzo, workdir, workdir_complete, dele, one_folder, joinables, zi
             rerun = True
             logging.info('Unzip starting on %s', workdir)
             if unzip(nzo, workdir, workdir_complete, dele, one_folder, new_zips):
-                error = True
+                error = 1
             logging.info('Unzip finished on %s', workdir)
             nzo.set_action_line()
 
@@ -305,16 +309,13 @@ def file_join(nzo, workdir, workdir_complete, delete, joinables):
     # Create matching sets from the list of files
     joinable_sets = {}
     joinable_set = None
-    set = num = None
     for joinable in joinables:
         head, tail = os.path.splitext(joinable)
         if tail == '.ts':
-            match, set, num = match_ts(joinable)
-        if not set:
-            set = head
-        if set not in joinable_sets:
-            joinable_sets[set] = []
-        joinable_sets[set].append(joinable)
+            head = match_ts(joinable)[1]
+        if head not in joinable_sets:
+            joinable_sets[head] = []
+        joinable_sets[head].append(joinable)
     logging.debug("joinable_sets: %s", joinable_sets)
 
     try:
@@ -460,7 +461,7 @@ def rar_unpack(nzo, workdir, workdir_complete, delete, one_folder, rars):
                     except OSError:
                         logging.warning(Ta('Deleting %s failed!'), latin1(brokenrar))
 
-    return not success, extracted_files
+    return fail, extracted_files
 
 
 def rar_extract(rarfile, numrars, one_folder, nzo, setname, extraction_path):
@@ -473,20 +474,24 @@ def rar_extract(rarfile, numrars, one_folder, nzo, setname, extraction_path):
     new_files = None
     rars = []
     if nzo.password:
-        passwords = [nzo.password]
+        logging.info('Got a password set by user')
+        passwords = [nzo.password.strip()]
     else:
         passwords = []
         # Append meta passwords, to prevent changing the original list
         passwords.extend(nzo.meta.get('password', []))
+        if passwords:
+            logging.info('Read %s passwords from meta data in NZB', len(passwords))
         pw_file = cfg.password_file.get_path()
         if pw_file:
             try:
                 pwf = open(pw_file, 'r')
                 lines = pwf.read().split('\n')
                 # Remove empty lines and space-only passwords and remove surrounding spaces
-                passwords.extend([pw.strip('\r\n ') for pw in lines if pw.strip('\r\n ')])
+                pws = [pw.strip('\r\n ') for pw in lines if pw.strip('\r\n ')]
+                passwords.extend(pws)
                 pwf.close()
-                logging.info('Read the passwords file %s', pw_file)
+                logging.info('Read %s passwords from file %s', len(pws), pw_file)
             except IOError:
                 logging.info('Failed to read the passwords file %s', pw_file)
 
@@ -515,7 +520,7 @@ def rar_extract(rarfile, numrars, one_folder, nzo, setname, extraction_path):
 
 def rar_extract_core(rarfile, numrars, one_folder, nzo, setname, extraction_path, password):
     """ Unpack single rar set 'rarfile' to 'extraction_path'
-        Return fail==0(ok)/fail==1(error)/fail==2(wrong password), new_files, rars
+        Return fail==0(ok)/fail==1(error)/fail==2(wrong password)/fail==3(crc-error), new_files, rars
     """
     start = time()
 
@@ -537,7 +542,7 @@ def rar_extract_core(rarfile, numrars, one_folder, nzo, setname, extraction_path
 
     ############################################################################
 
-    if one_folder:
+    if one_folder or cfg.flat_unpack():
         action = 'e'
     else:
         action = 'x'
@@ -610,7 +615,7 @@ def rar_extract_core(rarfile, numrars, one_folder, nzo, setname, extraction_path
             msg = ('[%s] '+Ta('ERROR: CRC failed in "%s"')) % (setname, latin1(filename))
             nzo.set_unpack_info('Unpack', unicoder(msg), set=setname)
             logging.warning(Ta('ERROR: CRC failed in "%s"'), latin1(setname))
-            fail = 1
+            fail = 3
 
         elif line.startswith('Write error'):
             nzo.fail_msg = T('Unpacking failed, write error or disk is full?')
@@ -639,8 +644,12 @@ def rar_extract_core(rarfile, numrars, one_folder, nzo, setname, extraction_path
             nzo.set_unpack_info('Unpack', unicoder(msg), set=setname)
             fail = 1
 
-        elif 'ncrypted file' in line and 'CRC failed' in line:
-            # unrar 4.x syntax
+        elif 'The specified password is incorrect' in line or \
+             ('ncrypted file' in line and (('CRC failed' in line) or ('Checksum error' in line))):
+            # unrar 3.x: "Encrypted file: CRC failed in oLKQfrcNVivzdzSG22a2xo7t001.part1.rar (password incorrect ?)"
+            # unrar 4.x: "CRC failed in the encrypted file oLKQfrcNVivzdzSG22a2xo7t001.part1.rar. Corrupt file or wrong password."
+            # unrar 5.x: "Checksum error in the encrypted file oLKQfrcNVivzdzSG22a2xo7t001.part1.rar. Corrupt file or wrong password."
+            # unrar 5.01 : "The specified password is incorrect."
             m = re.search('encrypted file (.+)\. Corrupt file', line)
             if not m:
                 # unrar 3.x syntax
@@ -648,7 +657,7 @@ def rar_extract_core(rarfile, numrars, one_folder, nzo, setname, extraction_path
             if m:
                 filename = TRANS(m.group(1)).strip()
             else:
-                filename = '???'
+                filename = os.path.split(rarfile)[1]
             nzo.fail_msg = T('Unpacking failed, archive requires a password')
             msg = ('[%s][%s] '+Ta('Unpacking failed, archive requires a password')) % (setname, latin1(filename))
             nzo.set_unpack_info('Unpack', unicoder(msg), set=setname)
@@ -664,7 +673,7 @@ def rar_extract_core(rarfile, numrars, one_folder, nzo, setname, extraction_path
             nzo.fail_msg = T('Unusable RAR file')
             msg = ('[%s][%s] '+ Ta('Unusable RAR file')) % (setname, latin1(filename))
             nzo.set_unpack_info('Unpack', unicoder(msg), set=setname)
-            fail = 1
+            fail = 3
 
         else:
             m = re.search(r'^(Extracting|Creating|...)\s+(.*?)\s+OK\s*$', line)
@@ -783,7 +792,7 @@ def unzip(nzo, workdir, workdir_complete, delete, one_folder, zips):
 def ZIP_Extract(zipfile, extraction_path, one_folder):
     """ Unzip single zip set 'zipfile' to 'extraction_path'
     """
-    if one_folder:
+    if one_folder or cfg.flat_unpack():
         option = '-j'  # Unpack without folders
     else:
         option = '-qq' # Dummy option
@@ -960,10 +969,6 @@ def PAR_Verify(parfile, parfile_nzf, nzo, setname, joinables, classic=False, sin
         command = [str(PAR2C_COMMAND), cmd, parfile]
         classic = True
 
-    for joinable in joinables:
-        if setname in joinable:
-            command.append(joinable)
-
     # Append the wildcard for this set
     wildcard = '%s*' % os.path.join(os.path.split(parfile)[0], setname)
     if single or len(globber(wildcard, None)) < 2:
@@ -1456,7 +1461,7 @@ def unrar_check(rar):
     """ Return True if correct version of unrar is found """
     if rar:
         try:
-            version = subprocess.Popen(rar, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).stdout.read()
+            version = run_simple(rar)
         except:
             return False
         m = re.search("RAR\s(\d+)\.(\d+)\s+.*Alexander Roshal", version)
@@ -1521,7 +1526,7 @@ def crc_check(path, target_crc):
 
 def analyse_show(name):
     """ Do a quick SeasonSort check and return basic facts """
-    job = SeriesSorter(name, None, None)
+    job = SeriesSorter(None, name, None, None)
     job.match(force=True)
     if job.is_match():
         job.get_values()
@@ -1620,3 +1625,13 @@ def get_from_url(url, timeout=None):
         except:
             output = None
     return output
+
+
+#------------------------------------------------------------------------------
+def run_simple(cmd):
+    """ Run simple external command and return output
+    """
+    p = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
+    txt = p.stdout.read()
+    p.wait()
+    return txt
