@@ -36,7 +36,7 @@ except ImportError:
 import sabnzbd
 from sabnzbd.constants import sample_match, GIGI, ATTRIB_FILE, JOB_ADMIN, \
                               DEFAULT_PRIORITY, LOW_PRIORITY, NORMAL_PRIORITY, \
-                              HIGH_PRIORITY, PAUSED_PRIORITY, TOP_PRIORITY, DUP_PRIORITY, \
+                              HIGH_PRIORITY, PAUSED_PRIORITY, TOP_PRIORITY, DUP_PRIORITY, REPAIR_PRIORITY, \
                               RENAMES_FILE, Status
 from sabnzbd.misc import to_units, cat_to_opts, cat_convert, sanitize_foldername, \
                          get_unique_path, get_admin_path, remove_all, format_source_url, \
@@ -45,6 +45,7 @@ from sabnzbd.misc import to_units, cat_to_opts, cat_convert, sanitize_foldername
 import sabnzbd.cfg as cfg
 from sabnzbd.trylist import TryList
 from sabnzbd.encoding import unicoder, platform_encode, latin1, name_fixer
+from sabnzbd.rating import Rating
 
 __all__ = ['Article', 'NzbFile', 'NzbObject']
 
@@ -532,7 +533,8 @@ NzbObjectMapper = (
     ('precheck',                     'precheck'),
     ('incomplete',                   'incomplete'),    # Was detected as incomplete
     ('reuse',                        'reuse'),
-    ('meta',                         'meta')           # Meta-date from 1.1 type NZB
+    ('meta',                         'meta'),          # Meta-date from 1.1 type NZB
+    ('unwanted_ext',                 'unwanted_ext')
 )
 
 class NzbObject(TryList):
@@ -544,7 +546,6 @@ class NzbObject(TryList):
 
         filename = platform_encode(filename)
         nzbname = platform_encode(nzbname)
-        nzbname = sanitize_foldername(nzbname)
 
         if pp is None:
             r = u = d = None
@@ -562,8 +563,11 @@ class NzbObject(TryList):
             dname, ext = os.path.splitext(work_name) # Used for folder name for final unpack
             if ext.lower() == '.nzb':
                 work_name = dname
-            work_name = sanitize_foldername(work_name)
         work_name, password = scan_password(work_name)
+        if not work_name:
+            work_name = filename
+        if nzb and work_name:
+            work_name = sanitize_foldername(work_name)
 
         self.work_name = work_name
         self.final_name = work_name
@@ -620,6 +624,7 @@ class NzbObject(TryList):
         self.oversized = False
         self.precheck = False
         self.incomplete = False
+        self.unwanted_ext = False
         self.reuse = reuse
         if self.status == Status.QUEUED and not reuse:
             self.precheck = cfg.pre_check()
@@ -673,7 +678,8 @@ class NzbObject(TryList):
         adir = os.path.join(wdir, JOB_ADMIN)
 
         # Duplicate checking, needs to be done before the backup
-        duplicate = (not reuse) and nzb and dup_check and sabnzbd.backup_exists(filename)
+        duplicate = (not reuse) and nzb and dup_check and sabnzbd.backup_exists(filename) \
+                    and priority != REPAIR_PRIORITY
 
         if reuse:
             remove_all(adir, 'SABnzbd_nz?_*')
@@ -750,7 +756,7 @@ class NzbObject(TryList):
                 cat = cat_convert(grp)
                 if cat:
                     break
-
+        
         if cfg.create_group_folders():
             self.dirprefix.append(self.group)
 
@@ -801,12 +807,12 @@ class NzbObject(TryList):
             self.priority = LOW_PRIORITY
 
         if duplicate and cfg.no_dupes() == 1:
-            logging.warning(Ta('Ignoring duplicate NZB "%s"'), filename)
+            if cfg.warn_dupl_jobs(): logging.warning(Ta('Ignoring duplicate NZB "%s"'), filename)
             self.purge_data(keep_basic=False)
             raise TypeError
 
         if duplicate or self.priority == DUP_PRIORITY:
-            logging.warning(Ta('Pausing duplicate NZB "%s"'), filename)
+            if cfg.warn_dupl_jobs(): logging.warning(Ta('Pausing duplicate NZB "%s"'), filename)
             self.duplicate = True
             self.pause()
             self.priority = NORMAL_PRIORITY
@@ -1035,25 +1041,27 @@ class NzbObject(TryList):
             prefix += Ta('TOO LARGE') + ' / ' #: Queue indicator for oversized job
         if self.incomplete and self.status == 'Paused':
             prefix += Ta('INCOMPLETE') + ' / ' #: Queue indicator for incomplete NZB
+        if self.unwanted_ext and self.status == 'Paused':
+            prefix += Ta('UNWANTED') + ' / ' #: Queue indicator for unwanted extensions
         if isinstance(self.wait, float):
             dif = int(self.wait - time.time() + 0.5)
             if dif > 0:
                 prefix += Ta('WAIT %s sec') % dif + ' / ' #: Queue indicator for waiting URL fetch
         if self.password:
-            return '%s%s / %s' % (name_fixer(prefix), self.final_name, self.password)
+            return '%s%s/%s' % (name_fixer(prefix), self.final_name, self.password)
         else:
             return '%s%s' % (name_fixer(prefix), self.final_name)
 
     @property
     def final_name_pw_clean(self):
         if self.password:
-            return '%s / %s' % (self.final_name, self.password)
+            return '%s/%s' % (self.final_name, self.password)
         else:
             return self.final_name
 
     def set_final_name_pw(self, name, password=None):
         if isinstance(name, str):
-            if password:
+            if password is not None:
                 name = platform_encode(name)
                 self.password = platform_encode(password)
             else:
@@ -1072,10 +1080,11 @@ class NzbObject(TryList):
         if self.encrypted:
             # If user resumes after encryption warning, no more auto-pauses
             self.encrypted = 2
-        # If user resumes after warning, reset duplicate/oversized/incomplete indicators
+        # If user resumes after warning, reset duplicate/oversized/incomplete/unwanted indicators
         self.duplicate = False
         self.oversized = False
         self.incomplete = False
+        self.unwanted_ext = False
 
     def add_parfile(self, parfile):
         if parfile not in self.files:
@@ -1262,6 +1271,19 @@ class NzbObject(TryList):
                         self.files[pos+1] = nzf
                         self.files[pos] = tmp_nzf
 
+    # Determine if rating information (including site identifier so rating can be updated)
+    # is present in metadata and if so store it
+    def update_rating(self):
+        try:
+            def _get_first_meta(type):
+                values = self.meta.get('x-rating-' + type, None)
+                return values[0] if values else None
+            rating_types = ['id', 'video', 'videocnt', 'audio', 'audiocnt', 'voteup' ,'votedown']
+            rs = map(_get_first_meta, rating_types)
+            Rating.do.add_rating(rs[0], self.nzo_id, rs[1], rs[2], rs[3], rs[4], rs[5], rs[6])
+        except:
+            pass
+                           
     ## end nzo.Mutators #######################################################
     ###########################################################################
     @property
@@ -1615,24 +1637,36 @@ def format_time_string(seconds, days=0):
     return completestr.strip()
 
 
-RE_PASSWORD1 = re.compile(r'([^/\\]+)[/\\](.+)')
-RE_PASSWORD2 = re.compile(r'(.+){{([^{}]+)}}$')
-RE_PASSWORD3 = re.compile(r'(.+)\s+password\s*=\s*(.+)$', re.I)
 def scan_password(name):
     """ Get password (if any) from the title
     """
     if 'http://' in name or 'https://' in name:
         return name, None
 
-    m = RE_PASSWORD1.search(name)
-    if not m:
-        m = RE_PASSWORD2.search(name)
-    if not m:
-        m = RE_PASSWORD3.search(name)
-    if m:
-        return m.group(1).strip('. '), m.group(2).strip()
-    else:
-        return name.strip('. '), None
+    braces = name.find('{{')
+    if braces < 0:
+        braces = len(name)
+    slash = name.find('/')
+
+    # Look for name/password, but make sure that '/' comes before any {{
+    if slash >= 0 and slash < braces and not 'password=' in name:
+        return name[:slash].strip('. '), name[slash+1:]
+        
+    # Look for "name password=password"
+    pw = name.find('password=')
+    if pw >= 0:
+        return name[:pw].strip('. '), name[pw+9:]
+
+    # Look for name{{password}}
+    if braces < len(name) and name.endswith('}}'):
+        return name[:braces].strip('. '), name[braces+2:len(name)-2]
+
+    # Look again for name/password
+    if slash >= 0:
+        return name[:slash].strip('. '), name[slash+1:]
+
+    # No password found
+    return name, None
 
 
 def get_attrib_file(path, size):
