@@ -39,6 +39,7 @@ from sabnzbd.constants import REPAIR_PRIORITY, TOP_PRIORITY, POSTPROC_QUEUE_FILE
      POSTPROC_QUEUE_VERSION, sample_match, JOB_ADMIN, Status, VERIFIED_FILE
 from sabnzbd.encoding import TRANS, unicoder
 from sabnzbd.newzbin import Bookmarks
+from sabnzbd.rating import Rating
 import sabnzbd.emailer as emailer
 import sabnzbd.dirscanner as dirscanner
 import sabnzbd.downloader
@@ -125,13 +126,14 @@ class PostProcessor(Thread):
         except:
             nzo_id = getattr(nzo, 'nzo_id', 'unknown id')
             logging.error(Ta('Failed to remove nzo from postproc queue (id)') + ' ' + nzo_id)
+            logging.info('Traceback: ', exc_info = True)
         self.save()
 
     def stop(self):
         """ Stop thread after finishing running job """
+        self.__stop = True
         self.queue.put(None)
         self.save()
-        self.__stop = True
 
     def empty(self):
         """ Return True if pp queue is empty """
@@ -160,12 +162,14 @@ class PostProcessor(Thread):
                 continue
 
             try:
-                nzo = self.queue.get(timeout=3)
+                nzo = self.queue.get(timeout=1)
             except Queue.Empty:
                 if check_eoq:
                     check_eoq = False
                     handle_empty_queue()
-                continue
+                    continue
+                else:
+                    nzo = self.queue.get()
 
             ## Stop job
             if not nzo:
@@ -238,7 +242,8 @@ def process_job(nzo):
         nzo.status = Status.FAILED
         nzo.save_attribs()
         all_ok = False
-        par_error = unpack_error = True
+        par_error = True
+        unpack_error = 1
 
     try:
 
@@ -268,7 +273,8 @@ def process_job(nzo):
             flag_repair = flag_unpack = False
             all_ok = cfg.empty_postproc() and empty
             if not all_ok:
-                par_error = unpack_error = True
+                par_error = True
+                unpack_error = 1
 
         script = nzo.script
         cat = nzo.cat
@@ -307,7 +313,10 @@ def process_job(nzo):
                 complete_dir = real_path(cfg.complete_dir.get_path(), catdir)
 
             ## TV/Movie/Date Renaming code part 1 - detect and construct paths
-            file_sorter = Sorter(cat)
+            if cfg.enable_meta():
+                file_sorter = Sorter(nzo, cat)
+            else:
+                file_sorter = Sorter(None, cat)
             complete_dir = file_sorter.detect(dirname, complete_dir)
             if file_sorter.sort_file:
                 one_folder = False
@@ -405,7 +414,7 @@ def process_job(nzo):
             if empty:
                 job_result = -1
             else:
-                job_result = int(par_error) + int(unpack_error)*2
+                job_result = int(par_error) + int(bool(unpack_error))*2
 
             if cfg.ignore_samples() > 0:
                 remove_samples(workdir_complete)
@@ -429,7 +438,8 @@ def process_job(nzo):
                 nzo.set_action_line(T('Running script'), unicoder(script))
                 nzo.set_unpack_info('Script', T('Running user script %s') % unicoder(script), unique=True)
                 script_log, script_ret = external_processing(script_path, workdir_complete, nzo.filename,
-                                                             msgid, dirname, cat, nzo.group, job_result)
+                                                             msgid, dirname, cat, nzo.group, job_result,
+                                                             nzo.nzo_info.get('failure', ''))
                 script_line = get_last_line(script_log)
                 if script_log:
                     script_output = nzo.nzo_id
@@ -476,6 +486,15 @@ def process_job(nzo):
         ## Force error for empty result
         all_ok = all_ok and not empty
 
+        ## Update indexer with results
+        if nzo.encrypted > 0:
+            Rating.do.update_auto_flag(nzo.nzo_id, Rating.FLAG_ENCRYPTED)
+        if empty:
+            hosts = map(lambda s: s.host, sabnzbd.downloader.Downloader.do.nzo_servers(nzo))
+            if not hosts: hosts = [None]
+            for host in hosts:
+                Rating.do.update_auto_flag(nzo.nzo_id, Rating.FLAG_EXPIRED, host)
+
         ## Show final status in history
         if all_ok:
             growler.send_notification(T('Download Completed'), filename, 'complete')
@@ -534,6 +553,10 @@ def process_job(nzo):
             logging.error(Ta('Error removing workdir (%s)'), workdir)
             logging.info("Traceback: ", exc_info = True)
 
+    # Use automatic retry link on par2 errors and encrypted/bad RARs
+    if par_error or unpack_error in (2, 3):
+        try_alt_nzb(nzo)
+
     return True
 
 
@@ -816,3 +839,9 @@ def remove_from_list(name, lst):
                 logging.debug('Popping %s', lst[n])
                 lst.pop(n)
                 return
+
+def try_alt_nzb(nzo):
+    """ Try to get a new NZB if available """
+    url = nzo.nzo_info.get('failure')
+    if url and cfg.new_nzb_on_failure():
+        sabnzbd.add_url(url, nzo.pp, nzo.script, nzo.cat, nzo.priority)
